"""Module information."""
import os

# The title and description of the package
__title__ = "pax8"
__description__ = """
    Python package for API requests to the Pax8 partner API
"""

# The version and build number
# Without specifying a unique number, you cannot overwrite packages in the PyPi repo
__version__ = os.getenv("RELEASE_NAME", "0.0.1" + os.getenv("GITHUB_RUN_ID", ""))

# Author and license information
__author__ = "Lars Scheibling"
__author_email__ = "lars@scheibling.se"
__license__ = "GnuPG 3.0"

# URL to the project
__url__ = f"https://github.com/scheibling/{__title__}"



"""The main part of the pytemplate-package."""
class PythonTemplate:
    """
    The PythonTemplate class does something.
    """
    def __init__(self, some_key: str):
        self.some_key = some_key
        self.some_key_list = [some_key]

    def __str__(self):
        return self.some_key

    def get_x_times(self, x: int):
        """
        Returns the class value X times.

        Args:
            x (int): How many times to return

        Returns:
            str: The class value some_key X times
        """
        return "".join([self.some_key for _ in range(x)])



#!/usr/bin/env python3
import os
from setuptools import setup, find_packages

# Repository name is the module name with dashes, ex. hit-py-template
# Module name can only contain underscores, so hit_py_template
# Also, configure the module under hit_py_template/__version__.py
repository_name = 'py-pax8'
module_name = 'pax8'
python_min_version = ">=3.6"

with open('requirements.txt', 'r') as f:
    required_packages = f.read().splitlines()

# Get key package details
about = {}  # type: ignore
here = os.path.abspath(os.path.dirname(__file__))

# Load the __version__.py file from the plugin directory
with open(os.path.join(here, 'src', module_name, '__version__.py')) as f:
    exec(f.read(), about)

# Load the README file and use it as the long_description for PyPI
with open('README.md', 'r') as f:
    readme = f.read()

# Package configuration - for reference see:
# https://setuptools.readthedocs.io/en/latest/setuptools.html#id9
setup(
    name=about['__title__'],
    description=about['__description__'],
    long_description=readme,
    long_description_content_type='text/markdown',
    version=about['__version__'],
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    packages=find_packages(where="src"),
    include_package_data=True,
    python_requires=python_min_version,
    install_requires=required_packages,
    license=about['__license__'],
    zip_safe=True,
    package_dir={"": "src"},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    keywords='python template package module cli',
    entry_points = {
        'console_scripts': [
            'pypax=pypax.cli:main'
        ]
    }
)


"""The file contains the CLI interface for the pytemplate package."""
import click
from cprint import cprint


@click.group(invoke_without_command=True)
@click.pass_context
def main(ctx):
    """
    Main class for CLI access

    Args:
        ctx (context): Click context
    """    
    ctx.ensure_object(dict)
    if ctx.invoked_subcommand is None:
        ctx.invoke(echo)


@main.command()
@click.argument("string_arg", nargs=1, required=False)
@click.option(
    "--string",
    "-s",
    default="Hello World!",
    required=False,
)
@click.option(
    "--color",
    "-c",
    default="ok",
    help="Output color (info, ok, warn, err)",
    required=False,
)
@click.pass_context
def echo(ctx, string, string_arg, color):
    """
    Echo a string with color

    Args:
        ctx (click.Context): The click context
        string (str): The string to echo (-s)
        string_arg (str): The string to echo (positional)
        color (str): The color to use (info, ok, warn, err)
    """
    prt = string_arg or string
    getattr(cprint, color)(prt)


if __name__ == "__main__":
    main()
